@@ -2,16 +2,6 @@ var dir_23ad537c0198e21f0d4ccda129f8fea1 =
 [
     [ "fieldmaster", "dir_be67fb4f416b8f5cd1a1cf48a68a95b6.html", "dir_be67fb4f416b8f5cd1a1cf48a68a95b6" ],
     [ "textfield", "dir_504c6ba70f121b79cad8dde8180f5114.html", "dir_504c6ba70f121b79cad8dde8180f5114" ],
-    [ "AccessibleEndnoteView.idl", "AccessibleEndnoteView_8idl.html", "AccessibleEndnoteView_8idl" ],
-    [ "AccessibleFootnoteView.idl", "AccessibleFootnoteView_8idl.html", "AccessibleFootnoteView_8idl" ],
-    [ "AccessibleHeaderFooterView.idl", "AccessibleHeaderFooterView_8idl.html", "AccessibleHeaderFooterView_8idl" ],
-    [ "AccessiblePageView.idl", "AccessiblePageView_8idl.html", "AccessiblePageView_8idl" ],
-    [ "AccessibleParagraphView.idl", "AccessibleParagraphView_8idl.html", "AccessibleParagraphView_8idl" ],
-    [ "AccessibleTextDocumentPageView.idl", "AccessibleTextDocumentPageView_8idl.html", "AccessibleTextDocumentPageView_8idl" ],
-    [ "AccessibleTextDocumentView.idl", "AccessibleTextDocumentView_8idl.html", "AccessibleTextDocumentView_8idl" ],
-    [ "AccessibleTextEmbeddedObject.idl", "AccessibleTextEmbeddedObject_8idl.html", "AccessibleTextEmbeddedObject_8idl" ],
-    [ "AccessibleTextFrameView.idl", "AccessibleTextFrameView_8idl.html", "AccessibleTextFrameView_8idl" ],
-    [ "AccessibleTextGraphicObject.idl", "AccessibleTextGraphicObject_8idl.html", "AccessibleTextGraphicObject_8idl" ],
     [ "AuthorDisplayFormat.idl", "AuthorDisplayFormat_8idl.html", "AuthorDisplayFormat_8idl" ],
     [ "AutoTextContainer.idl", "AutoTextContainer_8idl.html", "AutoTextContainer_8idl" ],
     [ "AutoTextEntry.idl", "AutoTextEntry_8idl.html", "AutoTextEntry_8idl" ],
