@@ -76,9 +76,11 @@ var namespacecom_1_1sun_1_1star_1_1chart2 =
     [ "Title", "servicecom_1_1sun_1_1star_1_1chart2_1_1Title.html", "servicecom_1_1sun_1_1star_1_1chart2_1_1Title" ],
     [ "XAnyDescriptionAccess", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XAnyDescriptionAccess.html", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XAnyDescriptionAccess" ],
     [ "XAxis", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XAxis.html", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XAxis" ],
+    [ "XChartColorStyle", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartColorStyle.html", null ],
     [ "XChartDocument", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartDocument.html", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartDocument" ],
     [ "XChartShape", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartShape.html", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartShape" ],
     [ "XChartShapeContainer", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartShapeContainer.html", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartShapeContainer" ],
+    [ "XChartStyle", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartStyle.html", null ],
     [ "XChartType", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartType.html", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartType" ],
     [ "XChartTypeContainer", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartTypeContainer.html", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartTypeContainer" ],
     [ "XChartTypeManager", "interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartTypeManager.html", null ],
