@@ -54,7 +54,7 @@ var searchData=
   ['finishengineevent_2eidl_51',['FinishEngineEvent.idl',['../FinishEngineEvent_8idl.html',1,'']]],
   ['finishreason_2eidl_52',['FinishReason.idl',['../FinishReason_8idl.html',1,'']]],
   ['fixedline_2eidl_53',['FixedLine.idl',['../FixedLine_8idl.html',1,'']]],
-  ['fixedtext_2eidl_54',['fixedtext.idl',['../report_2FixedText_8idl.html',1,'(Global Namespace)'],['../form_2component_2FixedText_8idl.html',1,'(Global Namespace)']]],
+  ['fixedtext_2eidl_54',['FixedText.idl',['../form_2component_2FixedText_8idl.html',1,'(Global Namespace)'],['../report_2FixedText_8idl.html',1,'(Global Namespace)']]],
   ['flagsequence_2eidl_55',['FlagSequence.idl',['../FlagSequence_8idl.html',1,'']]],
   ['flagsequencesequence_2eidl_56',['FlagSequenceSequence.idl',['../FlagSequenceSequence_8idl.html',1,'']]],
   ['flatconnectionproperties_2eidl_57',['FLATConnectionProperties.idl',['../FLATConnectionProperties_8idl.html',1,'']]],
@@ -74,65 +74,66 @@ var searchData=
   ['fontinfo_2eidl_71',['FontInfo.idl',['../FontInfo_8idl.html',1,'']]],
   ['fontmetrics_2eidl_72',['FontMetrics.idl',['../FontMetrics_8idl.html',1,'']]],
   ['fontpitch_2eidl_73',['FontPitch.idl',['../FontPitch_8idl.html',1,'']]],
-  ['fontrelief_2eidl_74',['fontrelief.idl',['../text_2FontRelief_8idl.html',1,'(Global Namespace)'],['../awt_2FontRelief_8idl.html',1,'(Global Namespace)']]],
+  ['fontrelief_2eidl_74',['FontRelief.idl',['../awt_2FontRelief_8idl.html',1,'(Global Namespace)'],['../text_2FontRelief_8idl.html',1,'(Global Namespace)']]],
   ['fontrequest_2eidl_75',['FontRequest.idl',['../FontRequest_8idl.html',1,'']]],
-  ['fontslant_2eidl_76',['FontSlant.idl',['../FontSlant_8idl.html',1,'']]],
-  ['fontstrikeout_2eidl_77',['FontStrikeout.idl',['../FontStrikeout_8idl.html',1,'']]],
-  ['fonttype_2eidl_78',['FontType.idl',['../FontType_8idl.html',1,'']]],
-  ['fontunderline_2eidl_79',['FontUnderline.idl',['../FontUnderline_8idl.html',1,'']]],
-  ['fontweight_2eidl_80',['FontWeight.idl',['../FontWeight_8idl.html',1,'']]],
-  ['fontwidth_2eidl_81',['FontWidth.idl',['../FontWidth_8idl.html',1,'']]],
-  ['footer_2eidl_82',['Footer.idl',['../Footer_8idl.html',1,'']]],
-  ['footershape_2eidl_83',['FooterShape.idl',['../FooterShape_8idl.html',1,'']]],
-  ['footnote_2eidl_84',['Footnote.idl',['../Footnote_8idl.html',1,'']]],
-  ['footnotelinestyle_2eidl_85',['FootnoteLineStyle.idl',['../FootnoteLineStyle_8idl.html',1,'']]],
-  ['footnotenumbering_2eidl_86',['FootnoteNumbering.idl',['../FootnoteNumbering_8idl.html',1,'']]],
-  ['footnotes_2eidl_87',['Footnotes.idl',['../Footnotes_8idl.html',1,'']]],
-  ['footnotesettings_2eidl_88',['FootnoteSettings.idl',['../FootnoteSettings_8idl.html',1,'']]],
-  ['forbiddencharacters_2eidl_89',['ForbiddenCharacters.idl',['../ForbiddenCharacters_8idl.html',1,'']]],
-  ['forcenewpage_2eidl_90',['ForceNewPage.idl',['../ForceNewPage_8idl.html',1,'']]],
-  ['form_2eidl_91',['Form.idl',['../Form_8idl.html',1,'']]],
-  ['formatcondition_2eidl_92',['FormatCondition.idl',['../FormatCondition_8idl.html',1,'']]],
-  ['formatelement_2eidl_93',['FormatElement.idl',['../FormatElement_8idl.html',1,'']]],
-  ['formattedfield_2eidl_94',['formattedfield.idl',['../form_2component_2FormattedField_8idl.html',1,'(Global Namespace)'],['../form_2control_2FormattedField_8idl.html',1,'(Global Namespace)'],['../report_2FormattedField_8idl.html',1,'(Global Namespace)']]],
-  ['formattedstring_2eidl_95',['FormattedString.idl',['../FormattedString_8idl.html',1,'']]],
-  ['formbuttontype_2eidl_96',['FormButtonType.idl',['../FormButtonType_8idl.html',1,'']]],
-  ['formcomponent_2eidl_97',['FormComponent.idl',['../FormComponent_8idl.html',1,'']]],
-  ['formcomponentpropertyhandler_2eidl_98',['FormComponentPropertyHandler.idl',['../FormComponentPropertyHandler_8idl.html',1,'']]],
-  ['formcomponents_2eidl_99',['FormComponents.idl',['../FormComponents_8idl.html',1,'']]],
-  ['formcomponenttype_2eidl_100',['FormComponentType.idl',['../FormComponentType_8idl.html',1,'']]],
-  ['formcontroller_2eidl_101',['formcontroller.idl',['../FormController_8idl.html',1,'(Global Namespace)'],['../runtime_2FormController_8idl.html',1,'(Global Namespace)']]],
-  ['formcontrollerdispatcher_2eidl_102',['FormControllerDispatcher.idl',['../FormControllerDispatcher_8idl.html',1,'']]],
-  ['formcontrolmodel_2eidl_103',['FormControlModel.idl',['../FormControlModel_8idl.html',1,'']]],
-  ['formfeature_2eidl_104',['FormFeature.idl',['../FormFeature_8idl.html',1,'']]],
-  ['formoperations_2eidl_105',['FormOperations.idl',['../FormOperations_8idl.html',1,'']]],
-  ['forms_2eidl_106',['forms.idl',['../form_2Forms_8idl.html',1,'(Global Namespace)'],['../sdb_2Forms_8idl.html',1,'(Global Namespace)']]],
-  ['formsubmitencoding_2eidl_107',['FormSubmitEncoding.idl',['../FormSubmitEncoding_8idl.html',1,'']]],
-  ['formsubmitmethod_2eidl_108',['FormSubmitMethod.idl',['../FormSubmitMethod_8idl.html',1,'']]],
-  ['formulalanguage_2eidl_109',['FormulaLanguage.idl',['../FormulaLanguage_8idl.html',1,'']]],
-  ['formulamapgroup_2eidl_110',['FormulaMapGroup.idl',['../FormulaMapGroup_8idl.html',1,'']]],
-  ['formulamapgroupspecialoffset_2eidl_111',['FormulaMapGroupSpecialOffset.idl',['../FormulaMapGroupSpecialOffset_8idl.html',1,'']]],
-  ['formulaopcodemapentry_2eidl_112',['FormulaOpCodeMapEntry.idl',['../FormulaOpCodeMapEntry_8idl.html',1,'']]],
-  ['formulaopcodemapper_2eidl_113',['FormulaOpCodeMapper.idl',['../FormulaOpCodeMapper_8idl.html',1,'']]],
-  ['formulaparser_2eidl_114',['FormulaParser.idl',['../FormulaParser_8idl.html',1,'']]],
-  ['formulaproperties_2eidl_115',['FormulaProperties.idl',['../FormulaProperties_8idl.html',1,'']]],
-  ['formularesult_2eidl_116',['FormulaResult.idl',['../FormulaResult_8idl.html',1,'']]],
-  ['formulatoken_2eidl_117',['FormulaToken.idl',['../FormulaToken_8idl.html',1,'']]],
-  ['frame_2eidl_118',['Frame.idl',['../Frame_8idl.html',1,'']]],
-  ['frameaction_2eidl_119',['FrameAction.idl',['../FrameAction_8idl.html',1,'']]],
-  ['frameactionevent_2eidl_120',['FrameActionEvent.idl',['../FrameActionEvent_8idl.html',1,'']]],
-  ['framecontrol_2eidl_121',['FrameControl.idl',['../FrameControl_8idl.html',1,'']]],
-  ['frameloader_2eidl_122',['FrameLoader.idl',['../FrameLoader_8idl.html',1,'']]],
-  ['frameloaderfactory_2eidl_123',['FrameLoaderFactory.idl',['../FrameLoaderFactory_8idl.html',1,'']]],
-  ['framescontainer_2eidl_124',['FramesContainer.idl',['../FramesContainer_8idl.html',1,'']]],
-  ['framesearchflag_2eidl_125',['FrameSearchFlag.idl',['../FrameSearchFlag_8idl.html',1,'']]],
-  ['ftpcontent_2eidl_126',['FTPContent.idl',['../FTPContent_8idl.html',1,'']]],
-  ['ftpcontentprovider_2eidl_127',['FTPContentProvider.idl',['../FTPContentProvider_8idl.html',1,'']]],
-  ['function_2eidl_128',['Function.idl',['../Function_8idl.html',1,'']]],
-  ['functionaccess_2eidl_129',['FunctionAccess.idl',['../FunctionAccess_8idl.html',1,'']]],
-  ['functionargument_2eidl_130',['FunctionArgument.idl',['../FunctionArgument_8idl.html',1,'']]],
-  ['functioncategory_2eidl_131',['FunctionCategory.idl',['../FunctionCategory_8idl.html',1,'']]],
-  ['functiondescription_2eidl_132',['FunctionDescription.idl',['../FunctionDescription_8idl.html',1,'']]],
-  ['functiondescriptionenumeration_2eidl_133',['FunctionDescriptionEnumeration.idl',['../FunctionDescriptionEnumeration_8idl.html',1,'']]],
-  ['functiondescriptions_2eidl_134',['FunctionDescriptions.idl',['../FunctionDescriptions_8idl.html',1,'']]]
+  ['fontsdisalloweditingrequest_2eidl_76',['FontsDisallowEditingRequest.idl',['../FontsDisallowEditingRequest_8idl.html',1,'']]],
+  ['fontslant_2eidl_77',['FontSlant.idl',['../FontSlant_8idl.html',1,'']]],
+  ['fontstrikeout_2eidl_78',['FontStrikeout.idl',['../FontStrikeout_8idl.html',1,'']]],
+  ['fonttype_2eidl_79',['FontType.idl',['../FontType_8idl.html',1,'']]],
+  ['fontunderline_2eidl_80',['FontUnderline.idl',['../FontUnderline_8idl.html',1,'']]],
+  ['fontweight_2eidl_81',['FontWeight.idl',['../FontWeight_8idl.html',1,'']]],
+  ['fontwidth_2eidl_82',['FontWidth.idl',['../FontWidth_8idl.html',1,'']]],
+  ['footer_2eidl_83',['Footer.idl',['../Footer_8idl.html',1,'']]],
+  ['footershape_2eidl_84',['FooterShape.idl',['../FooterShape_8idl.html',1,'']]],
+  ['footnote_2eidl_85',['Footnote.idl',['../Footnote_8idl.html',1,'']]],
+  ['footnotelinestyle_2eidl_86',['FootnoteLineStyle.idl',['../FootnoteLineStyle_8idl.html',1,'']]],
+  ['footnotenumbering_2eidl_87',['FootnoteNumbering.idl',['../FootnoteNumbering_8idl.html',1,'']]],
+  ['footnotes_2eidl_88',['Footnotes.idl',['../Footnotes_8idl.html',1,'']]],
+  ['footnotesettings_2eidl_89',['FootnoteSettings.idl',['../FootnoteSettings_8idl.html',1,'']]],
+  ['forbiddencharacters_2eidl_90',['ForbiddenCharacters.idl',['../ForbiddenCharacters_8idl.html',1,'']]],
+  ['forcenewpage_2eidl_91',['ForceNewPage.idl',['../ForceNewPage_8idl.html',1,'']]],
+  ['form_2eidl_92',['Form.idl',['../Form_8idl.html',1,'']]],
+  ['formatcondition_2eidl_93',['FormatCondition.idl',['../FormatCondition_8idl.html',1,'']]],
+  ['formatelement_2eidl_94',['FormatElement.idl',['../FormatElement_8idl.html',1,'']]],
+  ['formattedfield_2eidl_95',['FormattedField.idl',['../form_2component_2FormattedField_8idl.html',1,'(Global Namespace)'],['../form_2control_2FormattedField_8idl.html',1,'(Global Namespace)'],['../report_2FormattedField_8idl.html',1,'(Global Namespace)']]],
+  ['formattedstring_2eidl_96',['FormattedString.idl',['../FormattedString_8idl.html',1,'']]],
+  ['formbuttontype_2eidl_97',['FormButtonType.idl',['../FormButtonType_8idl.html',1,'']]],
+  ['formcomponent_2eidl_98',['FormComponent.idl',['../FormComponent_8idl.html',1,'']]],
+  ['formcomponentpropertyhandler_2eidl_99',['FormComponentPropertyHandler.idl',['../FormComponentPropertyHandler_8idl.html',1,'']]],
+  ['formcomponents_2eidl_100',['FormComponents.idl',['../FormComponents_8idl.html',1,'']]],
+  ['formcomponenttype_2eidl_101',['FormComponentType.idl',['../FormComponentType_8idl.html',1,'']]],
+  ['formcontroller_2eidl_102',['FormController.idl',['../FormController_8idl.html',1,'(Global Namespace)'],['../runtime_2FormController_8idl.html',1,'(Global Namespace)']]],
+  ['formcontrollerdispatcher_2eidl_103',['FormControllerDispatcher.idl',['../FormControllerDispatcher_8idl.html',1,'']]],
+  ['formcontrolmodel_2eidl_104',['FormControlModel.idl',['../FormControlModel_8idl.html',1,'']]],
+  ['formfeature_2eidl_105',['FormFeature.idl',['../FormFeature_8idl.html',1,'']]],
+  ['formoperations_2eidl_106',['FormOperations.idl',['../FormOperations_8idl.html',1,'']]],
+  ['forms_2eidl_107',['Forms.idl',['../form_2Forms_8idl.html',1,'(Global Namespace)'],['../sdb_2Forms_8idl.html',1,'(Global Namespace)']]],
+  ['formsubmitencoding_2eidl_108',['FormSubmitEncoding.idl',['../FormSubmitEncoding_8idl.html',1,'']]],
+  ['formsubmitmethod_2eidl_109',['FormSubmitMethod.idl',['../FormSubmitMethod_8idl.html',1,'']]],
+  ['formulalanguage_2eidl_110',['FormulaLanguage.idl',['../FormulaLanguage_8idl.html',1,'']]],
+  ['formulamapgroup_2eidl_111',['FormulaMapGroup.idl',['../FormulaMapGroup_8idl.html',1,'']]],
+  ['formulamapgroupspecialoffset_2eidl_112',['FormulaMapGroupSpecialOffset.idl',['../FormulaMapGroupSpecialOffset_8idl.html',1,'']]],
+  ['formulaopcodemapentry_2eidl_113',['FormulaOpCodeMapEntry.idl',['../FormulaOpCodeMapEntry_8idl.html',1,'']]],
+  ['formulaopcodemapper_2eidl_114',['FormulaOpCodeMapper.idl',['../FormulaOpCodeMapper_8idl.html',1,'']]],
+  ['formulaparser_2eidl_115',['FormulaParser.idl',['../FormulaParser_8idl.html',1,'']]],
+  ['formulaproperties_2eidl_116',['FormulaProperties.idl',['../FormulaProperties_8idl.html',1,'']]],
+  ['formularesult_2eidl_117',['FormulaResult.idl',['../FormulaResult_8idl.html',1,'']]],
+  ['formulatoken_2eidl_118',['FormulaToken.idl',['../FormulaToken_8idl.html',1,'']]],
+  ['frame_2eidl_119',['Frame.idl',['../Frame_8idl.html',1,'']]],
+  ['frameaction_2eidl_120',['FrameAction.idl',['../FrameAction_8idl.html',1,'']]],
+  ['frameactionevent_2eidl_121',['FrameActionEvent.idl',['../FrameActionEvent_8idl.html',1,'']]],
+  ['framecontrol_2eidl_122',['FrameControl.idl',['../FrameControl_8idl.html',1,'']]],
+  ['frameloader_2eidl_123',['FrameLoader.idl',['../FrameLoader_8idl.html',1,'']]],
+  ['frameloaderfactory_2eidl_124',['FrameLoaderFactory.idl',['../FrameLoaderFactory_8idl.html',1,'']]],
+  ['framescontainer_2eidl_125',['FramesContainer.idl',['../FramesContainer_8idl.html',1,'']]],
+  ['framesearchflag_2eidl_126',['FrameSearchFlag.idl',['../FrameSearchFlag_8idl.html',1,'']]],
+  ['ftpcontent_2eidl_127',['FTPContent.idl',['../FTPContent_8idl.html',1,'']]],
+  ['ftpcontentprovider_2eidl_128',['FTPContentProvider.idl',['../FTPContentProvider_8idl.html',1,'']]],
+  ['function_2eidl_129',['Function.idl',['../Function_8idl.html',1,'']]],
+  ['functionaccess_2eidl_130',['FunctionAccess.idl',['../FunctionAccess_8idl.html',1,'']]],
+  ['functionargument_2eidl_131',['FunctionArgument.idl',['../FunctionArgument_8idl.html',1,'']]],
+  ['functioncategory_2eidl_132',['FunctionCategory.idl',['../FunctionCategory_8idl.html',1,'']]],
+  ['functiondescription_2eidl_133',['FunctionDescription.idl',['../FunctionDescription_8idl.html',1,'']]],
+  ['functiondescriptionenumeration_2eidl_134',['FunctionDescriptionEnumeration.idl',['../FunctionDescriptionEnumeration_8idl.html',1,'']]],
+  ['functiondescriptions_2eidl_135',['FunctionDescriptions.idl',['../FunctionDescriptions_8idl.html',1,'']]]
 ];
